==> ld.so-1.8.1.tar.gz: ld.so-1.8.1/instldso.sh <==
#!/bin/sh

umask 022

echo 
echo 'This version of ld.so requires a Linux kernel version 1.2.13'
echo 'or later with ELF support compiled in.  Using the binfmt_elf'
echo 'module is not sufficient.  If your system does not meet these'
echo 'requirements, press Control-C now to abort the installation.'
echo 'Press Enter to continue.'
read

echo 'Expect some cache has wrong version warnings if upgrading'
echo 'to version 1.7.x for the first time.'

. ./Version.mk

PREFIX=

#if [ -f /etc/ld.so.cache ] ; then
#	echo Deleting old /etc/ld.so.cache
#	rm -f /etc/ld.so.cache
#fi

if [ ! -f $PREFIX/etc/ld.so.conf ] ; then
	echo Creating new /etc/ld.so.conf
	for dir in /usr/local/lib /usr/X11R6/lib /usr/X386/lib /usr/openwin/lib /lib/elf ; do
		if [ -d $PREFIX$dir ] ; then
			echo $dir >> $PREFIX/etc/ld.so.conf
		fi
	done
fi

if [ -f ld-so/ld.so ] ; then
	echo Installing ld.so
	install -c ld-so/ld.so $PREFIX/lib/ld.so.$VERSION
	mv -f $PREFIX/lib/ld.so.$VERSION $PREFIX/lib/ld.so
	ln -f $PREFIX/lib/ld.so $PREFIX/lib/ld.so.$VERSION
else
	echo Not installing a.out support
fi

echo Installing ld-linux.so
install -c d-link/ld-linux.so $PREFIX/lib/ld-linux.so.$VERSION
mv -f $PREFIX/lib/ld-linux.so.$VERSION $PREFIX/lib/ld-linux.so.$VMAJOR
ln -f $PREFIX/lib/ld-linux.so.$VMAJOR $PREFIX/lib/ld-linux.so.$VERSION
if [ -d $PREFIX/lib/elf ] ; then
	ln -sf ../ld-linux.so.$VMAJOR $PREFIX/lib/elf/ld-linux.so.$VMAJOR
fi

echo Installing libdl.so
install -c -m 644 d-link/libdl/dlfcn.h $PREFIX/usr/include/dlfcn.h
install -c d-link/libdl/libdl.so $PREFIX/lib/libdl.so.$VERSION
ln -sf libdl.so.$VERSION $PREFIX/lib/libdl.so

echo Installing ldd
install -c util/ldd $PREFIX/usr/bin
echo Installing lddstub
install -c util/lddstub $PREFIX/usr/lib/lddstub

echo Installing and running ldconfig
install -c util/ldconfig $PREFIX/sbin
$PREFIX/sbin/ldconfig

echo Installing manual pages
install -c -m 644 man/ldd.1 $PREFIX/usr/man/man1
install -c -m 644 man/ldconfig.8 man/ld.so.8 $PREFIX/usr/man/man8
install -c -m 644 man/dlopen.3 $PREFIX/usr/man/man3
ln -sf dlopen.3 $PREFIX/usr/man/man3/dlsym.3
ln -sf dlopen.3 $PREFIX/usr/man/man3/dlerror.3
ln -sf dlopen.3 $PREFIX/usr/man/man3/dlclose.3

echo Installation complete

==> ld.so-1.8.3.tar.gz: ld.so-1.8.3/instldso.sh <==
#!/bin/sh

umask 022

echo 
echo 'This version of ld.so requires a Linux kernel version 1.2.13'
echo 'or later with ELF support compiled in.  Using the binfmt_elf'
echo 'module is not sufficient.  If your system does not meet these'
echo 'requirements, press Control-C now to abort the installation.'
echo 'Press Enter to continue.'
if [ -z "$AUTOINST" ]; then
       read
fi

echo 'Expect some cache has wrong version warnings if upgrading'
echo 'from a version prior to 1.7.0.'

. ./Version.mk

if [ -z "$PREFIX" ]; then
       PREFIX=
fi

install -d -m 755 $PREFIX/etc
install -d -m 755 $PREFIX/sbin
install -d -m 755 $PREFIX/lib
install -d -m 755 $PREFIX/usr/bin
install -d -m 755 $PREFIX/usr/lib
install -d -m 755 $PREFIX/usr/include
install -d -m 755 $PREFIX/usr/man/man1
install -d -m 755 $PREFIX/usr/man/man3
install -d -m 755 $PREFIX/usr/man/man8
install -d -m 755 $PREFIX/usr/info

#if [ -f /etc/ld.so.cache ] ; then
#	echo Deleting old /etc/ld.so.cache
#	rm -f /etc/ld.so.cache
#fi

if [ ! -f $PREFIX/etc/ld.so.conf ] ; then
	echo Creating new /etc/ld.so.conf
	for dir in /usr/local/lib /usr/X11R6/lib /usr/X386/lib /usr/openwin/lib /lib/elf ; do
		if [ -d $PREFIX$dir ] ; then
			echo $dir >> $PREFIX/etc/ld.so.conf
		fi
	done
fi

if [ -f ld-so/ld.so ] ; then
	echo Installing ld.so
	install -c ld-so/ld.so $PREFIX/lib/ld.so.$VERSION
	mv -f $PREFIX/lib/ld.so.$VERSION $PREFIX/lib/ld.so
	ln -f $PREFIX/lib/ld.so $PREFIX/lib/ld.so.$VERSION
else
	echo Not installing a.out support
fi

echo Installing ld-linux.so
install -c d-link/ld-linux.so $PREFIX/lib/ld-linux.so.$VERSION
mv -f $PREFIX/lib/ld-linux.so.$VERSION $PREFIX/lib/ld-linux.so.$VMAJOR
ln -f $PREFIX/lib/ld-linux.so.$VMAJOR $PREFIX/lib/ld-linux.so.$VERSION

echo Installing libdl.so
install -c -m 644 d-link/libdl/dlfcn.h $PREFIX/usr/include/dlfcn.h
install -c d-link/libdl/libdl.so $PREFIX/lib/libdl.so.$VERSION
ln -sf libdl.so.$VERSION $PREFIX/lib/libdl.so

echo Installing ldd
install -c util/ldd $PREFIX/usr/bin
echo Installing lddstub
install -c util/lddstub $PREFIX/usr/lib/lddstub

echo Installing and running ldconfig
install -c util/ldconfig $PREFIX/sbin
$PREFIX/sbin/ldconfig

echo Installing manual and info pages
install -c -m 644 man/ldd.1 $PREFIX/usr/man/man1
install -c -m 644 man/ldconfig.8 man/ld.so.8 $PREFIX/usr/man/man8
install -c -m 644 man/dlopen.3 $PREFIX/usr/man/man3
ln -sf dlopen.3 $PREFIX/usr/man/man3/dlsym.3
ln -sf dlopen.3 $PREFIX/usr/man/man3/dlerror.3
ln -sf dlopen.3 $PREFIX/usr/man/man3/dlclose.3
install -c -m 644 man/ld.so.info $PREFIX/usr/info

echo Installation complete
